#import <QuickTime/QuickTime.h>
#import <Carbon/Carbon.h>

#import "MyObject.h"
#import "MyQuickDrawView.h"
#import "SpikeWave.h"

NSTimer *theTimer;

@implementation MyObject

//////////
//
// init
//
// Our controller's initialization method. Well
// add our self as an observer for application
// termination notifications, so we can perform
// cleanup when the application quits.
//
//////////

- (id)init
{
    /* we'll want to be called when the application
     quits so we can do any cleanup */
     
    [[NSNotificationCenter defaultCenter] addObserver:self
        selector:@selector(applicationWillTerminate:)
        name:@"NSApplicationWillTerminateNotification" object:NSApp];

    return self;
}

//////////
//
// awakeFromNib
//
// Called after all our objects are unarchived and
// connected but just before the interface is made visible
// to the user. We will do custom initialization of our
// objects here.
//
//////////

- (void)awakeFromNib
{
    //NSDictionary 	*dict;
    //NSString 		*windowTitle;
	OSErr 			err;
	
	/* setup SpikeWave Sound */
	[spikeWave setup];
	
	
    /* grab the name string for our window */
    //NSString *filePath	= [[NSBundle mainBundle] pathForResource:@"InfoPlist" ofType:@"strings"];
    //dict 				= [NSDictionary dictionaryWithContentsOfFile:filePath];
    //windowTitle 		= [dict objectForKey:@"MiniMungWindowTitleString"];

    /* set the window title */
	//[window setTitle:windowTitle];
    
    /* pass our view object to our MyQuickDrawView class so we can access methods
        in this class from our C code routines */
    saveQDViewObjectForCallback(view);
	
	/* now lets create a window and display the video data passed to us by the sequence grabber */
	err = [view doSeqGrab:[view bounds]];
	
	/* put up an error dialog to display any errors */
	if (err != noErr)
	{
		NSString *errorStr = [[NSString alloc] initWithFormat:@"%d" , err];
		int choice;

		/* now display error dialog and quit */
		choice = NSRunAlertPanel(@"Error", errorStr, @"OK", nil, nil);
		[errorStr release];
	}

}

- (IBAction)buttonClicked:(id)sender
{
	if([startButton state]==NSOnState){
		[spikeWave start];
		[startButton setTitle:@"running!"];
	}
	else{
		//[view endGrab];
		[spikeWave sstop];
		[startButton setTitle:@"Start"];
	}
}

/*- (IBAction)slider_moved:(id)sender
{
	double amp_frate;
	amp_frate = [slider_amp_frate doubleValue];
}

- (void)set_amp_frate:(double)amp_frate1
{
	amp_frate = amp_frate1;
}

- (double)amp_frate
{
	return amp_frate;
}*/

//////////
//
// applicationWillTerminate
//
// We'll release any objects we initialized
// in our init method.
//
//////////

- (void)applicationWillTerminate:(NSNotification *)notification
{
	//if([startButton state]==NSOnState){
		[view endGrab];    
	//}
}

@end

